@@ -244,7 +244,7 @@ proc ::tk::dialog::color::BuildDialog {w} {
             -relief sunken -bd 2 -highlightthickness 0
 	canvas $f.sel -height $data(PLGN_HEIGHT) \
 	    -width $data(canvasWidth) -highlightthickness 0 \
-            -bg [ttk::style lookup . -background]
+            -bg [style lookup . -background]
 	pack $f.color
 	pack $f.sel -expand yes -fill both
 
